@@ -5,9 +5,8 @@
 #' @param cellsize targeted area of the cell, in map units.
 #' @param type shape of the cell, "regular" for squares, "hexagonal" for hexagons. 
 #' @param var name of the numeric variable(s) in x to adapt to the grid (a vector).
-#' @param spdf deprecated, a SpatialPolygonsDataFrame.
-#' @param spdfid deprecated, identifier field in spdf, default to the first column 
-#' of the spdf data frame.  (optional)
+#' @param spdf defunct.
+#' @param spdfid defunct.
 #' @return A grid is returned as an sf object.
 #' @examples
 #' library(sf)
@@ -33,7 +32,7 @@
 #' par(opar)
 #' @export
 getGridLayer <- function(x, cellsize, type = "regular", var,
-                         spdf, spdfid = NULL){
+                         spdf, spdfid){
   # sp check
   if(missing(x)){
     x <- sf::st_as_sf(spdf)
@@ -41,8 +40,8 @@ getGridLayer <- function(x, cellsize, type = "regular", var,
   if (methods::is(x, 'Spatial')){
     x <- sf::st_as_sf(x)
   }
-  if(sum(missing(spdf), is.null(spdfid)) != 2){
-    warning("spdf and spdfid are deprecated; use x instead.", call. = FALSE)
+  if(sum(missing(spdf), missing(spdfid)) != 2){
+    stop("spdf and spdfid are defunct; use x instead.", call. = FALSE)
   }
   x$area <- sf::st_area(x)
   # get a grid
@@ -110,15 +109,3 @@ getGridAll <- function(x, cellsize, square){
 
 
 
-#' @title Compute Data for a Grid Layer
-#' @name getGridData
-#' @description Defunct
-#' @param x ...
-#' @param df ...
-#' @param dfid ...
-#' @param var ...
-#' @export
-#' @keywords internal
-getGridData <- function(x, df, dfid = NULL, var){
-  .Defunct(msg = "This function is defunct, use getGridLayer instead.")
-}
\ No newline at end of file
